from typing import Iterator

class MultiArg:
    def __init__(
        self, args: list[str] | str, fill: str = ..., splitchar: str = ...
    ) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[str]: ...
    def __getitem__(self, key: int) -> str: ...
